==> apache-druid-30.0.0-src.tar.gz: apache-druid-30.0.0-src/processing/src/main/java/org/apache/druid/indexer/report/SingleFileTaskReportFileWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexer.report;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.druid.java.util.common.FileUtils;
import org.apache.druid.java.util.common.logger.Logger;

import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStream;

public class SingleFileTaskReportFileWriter implements TaskReportFileWriter
{
  private static final Logger log = new Logger(SingleFileTaskReportFileWriter.class);

  private final File reportsFile;
  private ObjectMapper objectMapper;

  public SingleFileTaskReportFileWriter(File reportsFile)
  {
    this.reportsFile = reportsFile;
  }

  @Override
  public void write(String taskId, TaskReport.ReportMap reports)
  {
    try {
      final File reportsFileParent = reportsFile.getParentFile();
      if (reportsFileParent != null) {
        FileUtils.mkdirp(reportsFileParent);
      }

      try (final FileOutputStream outputStream = new FileOutputStream(reportsFile)) {
        writeReportToStream(objectMapper, outputStream, reports);
      }
    }
    catch (Exception e) {
      log.error(e, "Encountered exception in write().");
    }
  }

  @Override
  public void setObjectMapper(ObjectMapper objectMapper)
  {
    this.objectMapper = objectMapper;
  }

  public static void writeReportToStream(
      final ObjectMapper objectMapper,
      final OutputStream outputStream,
      final TaskReport.ReportMap reports
  ) throws Exception
  {
    objectMapper.writeValue(outputStream, reports);
  }
}

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/processing/src/main/java/org/apache/druid/indexer/report/SingleFileTaskReportFileWriter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.indexer.report;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.druid.java.util.common.FileUtils;
import org.apache.druid.java.util.common.logger.Logger;

import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.file.Files;

public class SingleFileTaskReportFileWriter implements TaskReportFileWriter
{
  private static final Logger log = new Logger(SingleFileTaskReportFileWriter.class);

  private final File reportsFile;
  private ObjectMapper objectMapper;

  public SingleFileTaskReportFileWriter(File reportsFile)
  {
    this.reportsFile = reportsFile;
  }

  @Override
  public void write(String taskId, TaskReport.ReportMap reports)
  {
    try (final OutputStream outputStream = openReportOutputStream(taskId)) {
      writeReportToStream(objectMapper, outputStream, reports);
    }
    catch (Exception e) {
      log.error(e, "Encountered exception in write().");
    }
  }

  @Override
  public OutputStream openReportOutputStream(String taskId) throws IOException
  {
    final File reportsFileParent = reportsFile.getParentFile();
    if (reportsFileParent != null) {
      FileUtils.mkdirp(reportsFileParent);
    }

    return Files.newOutputStream(reportsFile.toPath());
  }

  @Override
  public void setObjectMapper(ObjectMapper objectMapper)
  {
    this.objectMapper = objectMapper;
  }

  public static void writeReportToStream(
      final ObjectMapper objectMapper,
      final OutputStream outputStream,
      final TaskReport.ReportMap reports
  ) throws Exception
  {
    objectMapper.writeValue(outputStream, reports);
  }
}
